@@ -1,5 +1,5 @@
 `BIB.test` <-
-		function (block, trt, y, test = c("lsd","tukey","duncan","waller","snk"), alpha = 0.05, group = TRUE)
+		function (block, trt, y, test = c("lsd","tukey","duncan","waller","snk"), alpha = 0.05, group = TRUE,console=FALSE)
 {
 	test<-match.arg(test)
 	block.unadj <- as.factor(block)
@@ -34,97 +34,104 @@
 	mean.adj <- mean(y,na.rm=TRUE) + Q * k/(lambda * ntr)
 	StdError.adj <- sqrt(MSerror * (1 + k * r * (ntr - 1)/(lambda *
 							ntr))/(r * ntr))
+	CV<-cv.model(model)
+	Mean<-mean(y,na.rm=TRUE)
+	if(console){
 	cat("\nANALYSIS BIB: ", name.y, "\nClass level information\n")
 	cat("\nBlock: ", unique(as.character(block)))
 	cat("\nTrt  : ", unique(as.character(trt)))
 	cat("\n\nNumber of observations: ", length(y), "\n\n")
 	print(anova(model))
-	CV<-cv.model(model)
-	Mean<-mean(y,na.rm=TRUE)
 	cat("\ncoefficient of variation:", round(CV, 1),
 			"%\n")
 	cat(name.y, "Means:", Mean, "\n\n")
 	cat(paste(name.t,",",sep="")," statistics\n\n")
+    }
 	nameTrt<-row.names(Y)
 	std.err <- sds/sqrt(r)
 	means <-data.frame( means=Y/r,mean.adj, SE=StdError.adj,r,std.err,Min.=mi,Max.=ma)
 	rownames(means)<-nameTrt
 	names(means)[1]<-name.y
-	print(means)
-	
+	if(console)print(means)
 	parameter <- k/(lambda * ntr)
 	snk<-0
 	if (test == "lsd") {
 		Tprob <- qt(1 - alpha/2, DFerror)
+		if(console){
 		cat("\nLSD test")
 		cat("\nStd.diff   :", sdtdif)
 		cat("\nAlpha      :", alpha)
-		cat("\nLSD        :", Tprob * sdtdif)
+		cat("\nLSD        :", Tprob * sdtdif)}
 	}
 	if (test == "tukey") {
 		Tprob <- qtukey(1 - alpha, ntr, DFerror)
 		sdtdif<-sdtdif/sqrt(2)
+		if(console){
 		cat("\nTukey")
 		cat("\nAlpha      :", alpha)
 		cat("\nStd.err    :", sdtdif)
-		cat("\nHSD        :", Tprob * sdtdif)
+		cat("\nHSD        :", Tprob * sdtdif)}
 		parameter <- parameter/2
 	}
 	if (test == "waller") {
 		K <- 650 - 16000 * alpha + 1e+05 * alpha^2
 		Tprob <- waller(K, ntr - 1, DFerror, Fvalue)
+		if(console){
 		cat("\nWaller-Duncan K-ratio")
 		cat("\nThis test minimizes the Bayes risk under additive")
 		cat("\nloss and certain other assumptions.\n")
 		cat("\nk Ratio    : ", K)
-		cat("\nMSD        :", Tprob * sdtdif)
+		cat("\nMSD        :", Tprob * sdtdif)}
 	}
 	if (test == "snk") {
 		snk<-1
 		sdtdif<-sdtdif/sqrt(2)
-		cat("\nStudent Newman Keuls")
-		cat("\nAlpha     :", alpha)
-		cat("\nStd.err   :", sdtdif)
 		Tprob <- qtukey(1-alpha,2:ntr, DFerror)
 		SNK <- Tprob * sdtdif
 		names(SNK)<-2:ntr
+		if(console){cat("\nStudent Newman Keuls")
+		cat("\nAlpha     :", alpha)
+		cat("\nStd.err   :", sdtdif)
 		cat("\nCritical Range\n")
-		print(SNK)
+		print(SNK)}
 	}
 	if (test == "duncan") {
 		snk<-2
 		sdtdif<-sdtdif/sqrt(2)
-		cat("\nDuncan's new multiple range test")
-		cat("\nAlpha     :", alpha)
-		cat("\nStd.err   :", sdtdif)
 		Tprob <- qtukey((1-alpha)^(1:(ntr-1)),2:ntr, DFerror)
 		duncan <- Tprob * sdtdif
 		names(duncan)<-2:ntr
+		if(console){
+		cat("\nDuncan's new multiple range test")
+		cat("\nAlpha     :", alpha)
+		cat("\nStd.err   :", sdtdif)
 		cat("\n\nCritical Range\n")
-		print(duncan)
+		print(duncan)}
 	}
 	E <- lambda * ntr/(r * k)
+	if(console){
 	cat("\nParameters BIB")
 	cat("\nLambda     :", lambda)
 	cat("\ntreatmeans :", ntr)
 	cat("\nBlock size :", k)
 	cat("\nBlocks     :", b)
 	cat("\nReplication:", r, "\n")
-	cat("\nEfficiency factor", E, "\n\n<<< Book >>>\n")
+	cat("\nEfficiency factor", E, "\n\n<<< Book >>>\n")}
 	parameters<-data.frame(lambda= lambda,treatmeans=ntr,blockSize=k,blocks=b,r=r)
 	statistics<-data.frame(Mean=Mean,Efficiency=E,CV=CV)
 	rownames(parameters)<-" "
 	rownames(statistics)<-" "
 		if (group) {
+		if(console){
 		cat("\nMeans with the same letter are not significantly different.")
-		cat("\n\nComparison of treatments\n\nGroups, Treatments and means\n")
+		cat("\n\nComparison of treatments\n\nGroups, Treatments and means\n")}
 		if (snk==0)
 			groups <- order.group(names(mean.adj), as.numeric(mean.adj),
 					rep(1, ntr), MSerror, Tprob, std.err = StdError.adj,
-					parameter,sdtdif=sdtdif)
+					parameter,sdtdif=sdtdif,console=console)
 		else groups <- order.group(names(mean.adj), as.numeric(mean.adj),
 					rep(1, ntr), MSerror, Tprob, std.err = StdError.adj,
-					parameter, snk=snk,DFerror,alpha,sdtdif=sdtdif)
+					parameter, snk=snk,DFerror,alpha,sdtdif=sdtdif,console=console)
 		groups<-groups[,1:3]
 		names(groups)[2]<-"mean.adj"
 		comparison<-NULL
@@ -172,11 +179,11 @@
 			significant = abs(dif) > Tprob * sdtdif
 		tr.i <- nameTrt[comb[1, ]]
 		tr.j <- nameTrt[comb[2, ]]
-		cat("\nComparison between treatments means\n")
+		if(console)cat("\nComparison between treatments means\n")
 		if (test == "waller") comparison<-data.frame("Difference" = dif, significant)
 		else  comparison<-data.frame("Difference" = dif, pvalue=pvalue,"sig."=sig)
 		rownames(comparison)<-paste(tr.i,tr.j,sep=" - ")
-		print(comparison)
+		if(console)print(comparison)
 		groups <- NULL
 	}
 	invisible(list(parameters=parameters,statistics=statistics,comparison=comparison,means=means,groups=groups))
