@@ -1,5 +1,5 @@
 `HSD.test` <-
-		function (y, trt, DFerror, MSerror, alpha=0.05, group=TRUE,main = NULL)
+function (y, trt, DFerror, MSerror, alpha=0.05, group=TRUE,main = NULL,console=FALSE)
 {
 	name.y <- paste(deparse(substitute(y)))
 	name.t <- paste(deparse(substitute(trt)))
@@ -13,7 +13,7 @@
 		nipch<- length(ipch)
 		for(i in 1:nipch){
 			if (is.na(ipch[i]))
-				return(cat("Name: ", trt, "\n", names(A)[-1], "\n"))
+				return(if(console)cat("Name: ", trt, "\n", names(A)[-1], "\n"))
 		}
 		name.t<- names(A)[ipch][1]
 		trt <- A[, ipch]
@@ -33,12 +33,13 @@
 	nn <-   tapply.stat(junto[,1],junto[,2],stat="length") # change
 	mi<-tapply.stat(junto[,1],junto[,2],stat="min") # change
 	ma<-tapply.stat(junto[,1],junto[,2],stat="max") # change
-	means<-data.frame(means,std.err=sds[,2]/sqrt(nn[,2]),r=nn[,2],Min.=mi[,2],Max.=ma[,2])
+	means<-data.frame(means,std.err=sqrt(MSerror)/sqrt(nn[,2]),r=nn[,2],Min.=mi[,2],Max.=ma[,2])
 	names(means)[1:2]<-c(name.t,name.y)
 #   row.names(means)<-means[,1]
 	ntr<-nrow(means)
 	Tprob <- qtukey(1-alpha,ntr, DFerror)
 	nr<- 1/mean(1/nn[,2])
+	if(console){
 	cat("\nStudy:", main)
 	cat("\n\nHSD Test for",name.y,"\n")
 	cat("\nMean Square Error: ",MSerror,"\n\n")
@@ -46,18 +47,20 @@
 	print(data.frame(row.names = means[,1], means[,-1]))
 	cat("\nalpha:",alpha,"; Df Error:",DFerror,"\n")
 	cat("Critical Value of Studentized Range:", Tprob,"\n")
+	}
 	HSD <- Tprob * sqrt(MSerror/nr)
 	
 	if (length(unique(nn[,2]))!=1) {
-		cat("\nHarmonic Mean of Cell Sizes ", nr )
+	if(console)cat("\nHarmonic Mean of Cell Sizes ", nr )
 statistics<-data.frame(Mean=Mean,CV=CV,MSerror=MSerror,HSD=HSD, r.harmonic=nr)
 	}
 	else statistics<-data.frame(Mean=Mean,CV=CV,MSerror=MSerror,HSD=HSD)
 	if (group) {
+	if(console){
 		cat("\nHonestly Significant Difference:",HSD,"\n")
 		cat("\nMeans with the same letter are not significantly different.")
-		cat("\n\nGroups, Treatments and means\n")
-		groups <- order.group(means[,1], means[,2], means[,4], MSerror, Tprob,means[,3], parameter=0.5)
+		cat("\n\nGroups, Treatments and means\n")}
+		groups <- order.group(means[,1], means[,2], means[,4], MSerror, Tprob,means[,3], parameter=0.5,console=console)
 	comparison=NULL
 	groups <- data.frame(groups[,1:3])
 	}
@@ -92,8 +95,8 @@ statistics<-data.frame(Mean=Mean,CV=CV,MSerror=MSerror,HSD=HSD, r.harmonic=nr)
 		tr.j <- means[comb[2, ],1]
 		comparison<-data.frame("Difference" = dif, pvalue=pvalue,"sig."=sig,LCL,UCL)
 		rownames(comparison)<-paste(tr.i,tr.j,sep=" - ")
-		cat("\nComparison between treatments means\n\n")
-		print(comparison)
+		if(console){cat("\nComparison between treatments means\n\n")
+		print(comparison)}
 		groups=NULL
 		#groups<-data.frame(trt= means[,1],means= means[,2],M="",N=means[,4],std.err=means[,3])
 	}
